@@ -640,6 +640,9 @@ class ResponseObject(object):
 	@property
 	def __name__(self):
 		return self.instance()
+	# return raw data.
+	def raw(self):
+		return self.dict()
 
 # initialized objects.
 r3sponse = R3sponse()
